rnalysis.filtering.FoldChangeFilter.filter\_percentile
======================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.filter_percentile